Bootstrap non-catch share data

bootstrap_discard(
  data,
  conf_data_check,
  dir = NULL,
  boot_number = 10000,
  boot_variable = "r_port_group",
  seed_number = NULL
)

Arguments

data

A data frame of WCGOP catch data filtered down to non-catch share data created by get_discard_rates().

conf_data_check

Dataframe with the number of observations, trips, and vessels by fleet created by check_confidential().

dir

Directory where output will be saved. The directory where the file should be saved. If dir = NULL no output will be saved.

boot_number

An integer to determine the number of bootstraps to draw in order to estimate the yearly variance for non-catch share data.

boot_variable

String to defined the column name in WCGOP catch data to group data for bootstrapping.

seed_number

An integer to define the seed number when using set.seed() for reproducibility.

Details

Bootstrap samples across year, fleet, and return port group.

Author

Chantel Wetzel, Allan Hicks, and Jason Jannot