Function that calculates discards for the catch share vessels

calc_cs_discards(data, conf_data_check, dir = NULL)

Arguments

data

A data frame of WCGOP catch data filtered down to only catch share data created by get_discard_rates(). group data for bootstrapping.

conf_data_check

Dataframe with the number of observations, trips, and vessels by fleet created by check_confidential().

dir

Directory where output will be saved. The directory where the file should be saved. If dir = NULL no output will be saved.

Author

Chantel Wetzel