Review rates for EM data was reduced below 100% starting in 2024. This change requires data these data to not be treated as a census but rather use bootstrapping to estimate discard rates and uncertainty. em_catch_data starting in 2024 are added to catch_data and are categorized as non-catch share for bootstrapping

combine_catch_data(catch_data, em_catch_data)

Arguments

catch_data

A data frame of WCGOP catch data that includes all species.

em_catch_data

A data frame of WCGOP EM catch data that includes all species.

Value

dataframe

Author

Chantel Wetzel