Bootstrap uncertainty and summarize WCGOP discard data

combine_cs_discards(cs_data, em_data, dir = NULL)

Arguments

cs_data

Data object of the processed catch share discards from the OBCatch data created by get_discard_rates().

em_data

Data object of the processed em catch share discards from the EMCatch data created by get_discard_rates().

dir

Directory where output will be saved. The directory where the file should be saved. If dir = NULL no output will be saved.

Author

Chantel Wetzel