Calculate the totals and proportions by gear and catch shares. These data are not grouped in order to see the amounts for each gear and catch share sector prior to combining for WCGOP data processing.

plot_gemm(data, plot = 1:2, dir = NULL)

Arguments

data

Data frame of gemm data pulled using nwfscSurvey::pull_gemm()

plot

A vector of integers to specify which plots you would like. The default is to print or save both figures, i.e., plot = 1:2. Integers correspond to the following figures:

  1. Catch, landings, and discard by catch share and gear

  2. Proportion of catch, landings, and discards by catch share and gear

dir

Directory where output will be saved. The directory where the file should be saved. If dir = NULL no output will be saved.

Author

Chantel Wetzel