Visualize biological discard data

plot_wcgop_bio(
  data,
  species_name,
  gear_groups,
  gear_names,
  fleet_groups,
  fleet_names,
  fleet_colname = "r_state",
  dir = NULL,
  comp_column = "length"
)

Arguments

data

A data frame of WCGOP biological data that includes all species. The full biological data frame is filtered down to selected species and to include only discard data (catch_disposition == "D").

species_name

Species name to process discard biological data for. The casing needs to match WCGOP biological species column that capitalizes the first letter of each name (e.g., Canary Rockfish, Sablefish).

gear_groups

List object of gear names to group together based on the WCGOP gear column, example: list(c("Bottom Trawl", "Midwater Trawl"), c("Hook & Line", "Pot", "Fixed Gear")).

gear_names

Vector of gear group names that needs to match the length of the gear_groups object and align in order of the assigned names. For example, if gear_groups = list(c("Bottom Trawl", "Midwater Trawl"), c("Hook & Line", "Pot", "Fixed Gear")) then gear_names = c("trawl", "fixed gear")).

fleet_groups

List object of how to combine the data to define fleet groups. For example, list(c("WA", "OR"), "CA") would define WA-OR and CA fleets.

fleet_names

Vector of fleet names that needs to match the length of the fleet_groups object and align in order of the assigned names. For example, the fleet_names should be c("OR-WA", "CA") to align with a fleet_groups of list(c("WA", "OR"), "CA").

fleet_colname

Column in the biological data that should be used to define the fleet areas. Commonly used columns is r_state which can allow you to group or split data by state. The area column can be used to split data north and south of 4010 N. lat.

dir

Directory where output will be saved. The directory where the file should be saved. If dir = NULL no output will be saved.

Value

Boxplot of discard length/age by gear group and year.

Author

Chantel Wetzel