Weight discard rates between catch share and non-catch share

weight_discard_rates(
  weight_data,
  ncs_data,
  cs_data,
  dir = NULL,
  min_sd = 0.015
)

Arguments

weight_data

Data frame of the alternative GEMM or GEMM data provided by the FOS team for calculating data weights created by get_weights().

ncs_data

Data object of the processed non-catch share discards from the catch data created by get_discard_rates().

cs_data

Data object of the processed catch share discards from catch data created by get_discard_rates().

dir

Directory where output will be saved. The directory where the file should be saved. If dir = NULL no output will be saved.

min_sd

Numeric value that is defines minimum standard deviation to apply to catch share observations with full observer coverage.

Value

dataframe

Author

Chantel Wetzel