bootstrap.RdBootstrap non-catch share data
bootstrap(data, boot_number)A list of data separated by year, fleet, and return port group
created by bootstrap_discard().
An integer to determine the number of bootstraps to draw in order to estimate the yearly variance for non-catch share data.
Bootstrap samples across the number of unique vessels in each year, fleet, and return port group.