bootstrap_discard.RdBootstrap non-catch share data
bootstrap_discard(
data,
conf_data_check,
dir = NULL,
boot_number = 10000,
boot_variable = "r_port_group",
seed_number = NULL
)A data frame of WCGOP catch data filtered down to non-catch share data
created by get_discard_rates().
Dataframe with the number of observations, trips, and
vessels by fleet created by check_confidential().
Directory where output will be saved. The directory where the file should be saved. If dir = NULL no output will be saved.
An integer to determine the number of bootstraps to draw in order to estimate the yearly variance for non-catch share data.
String to defined the column name in WCGOP catch data to group data for bootstrapping.
An integer to define the seed number when using set.seed()
for reproducibility.
Bootstrap samples across year, fleet, and return port group.