calc_comps.RdCalculate expanded discard composition
calc_comps(dir = NULL, data, comp_bins, comp_column_name = "length")Directory where output will be saved. The directory where the file should be saved. If dir = NULL no output will be saved.
A data frame of WCGOP biological data created by get_biological_data()
that includes the data expansions for length or age data.
Length or age bins to apply to the composition data.
Column name for the type of composition data to process (e.g., "length" or "age")