create_groups.RdCreate gear and fleet groups
create_groups(
data,
gear_groups,
gear_names,
fleet_colname,
fleet_groups,
fleet_names
)A data frame of WCGOP catch data that includes all species.
List object of gear names to group together based on the WCGOP gear column, example: list(c("Bottom Trawl", "Midwater Trawl"), c("Hook & Line", "Pot", "Fixed Gear")).
Vector of gear group names that needs to match the length of
the gear_groups object and align in order of the assigned names.
For example, if gear_groups = list(c("Bottom Trawl", "Midwater Trawl"),
c("Hook & Line", "Pot", "Fixed Gear")) then gear_names = c("trawl", "fixed gear")).
Column in the biological data that should be used to
define the fleet areas. Commonly used columns is r_state which can allow you
to group or split data by state. The area column can be used to split data
north and south of 4010 N. lat.
List object of how to combine the data to define fleet groups. For example, list(c("WA", "OR"), "CA") would define WA-OR and CA fleets.
Vector of fleet names that needs to match the length of
the fleet_groups object and align in order of the assigned names. For
example, the fleet_names should be c("OR-WA", "CA") to align with a
fleet_groups of list(c("WA", "OR"), "CA").