format_gemm.RdFormat GEMM data to match the WCGOP
format_gemm(data, species_name, areas_to_keep, gears_to_keep, dir = NULL)Dataframe of GEMM data from nwfscSurvey::pull_gemm()
A string to specify the species name that data should be summarized for. The string should match the name in the gemm data file and needs to be a single species.
A vector of area names in the GEMM grouping column to filter the data for.
A vector of gear names to filter the data for. Gear is defined based on the sector column in the GEMM dataframe with the gear definitions based on WCGOP gear-sector specifications.
Directory where output will be saved. The directory where the file should be saved. If dir = NULL no output will be saved.
dataframe