plot_gemm.RdCalculate the totals and proportions by gear and catch shares. These data are not grouped in order to see the amounts for each gear and catch share sector prior to combining for WCGOP data processing.
plot_gemm(data, plot = 1:2, dir = NULL)Data frame of gemm data pulled using nwfscSurvey::pull_gemm()
A vector of integers to specify which plots you would like. The
default is to print or save both figures, i.e., plot = 1:2. Integers
correspond to the following figures:
Catch, landings, and discard by catch share and gear
Proportion of catch, landings, and discards by catch share and gear
Directory where output will be saved. The directory where the file should be saved. If dir = NULL no output will be saved.